@@ -229,10 +229,8 @@ class Session:
     @property
     def npexp_path(self) -> pathlib.Path:
         """np-exp root / folder (may not exist)"""
-        with contextlib.suppress(AttributeError):
-            return self._npexp_path    
-        self._npexp_path = NPEXP_ROOT / self.folder
-        return self.npexp_path
+        return NPEXP_ROOT / 'habituation' / self.folder if self.is_hab else NPEXP_ROOT / self.folder
+    
     @property
     def lims_path(self) -> pathlib.Path | None:
         """Corresponding directory in lims, if one can be found"""
